@@ -2,24 +2,32 @@
 from __future__ import unicode_literals
 
 MESSAGES = {
-    "Also available in": "Също достъпно в",
+    "%d min remaining to read": "",
+    "Also available in:": "Също достъпно в:",
     "Archive": "Архив",
     "Categories": "Категории",
+    "Comments": "",
     "LANGUAGE": "Български",
-    "More posts about": "Още публикации относно ",
+    "Languages:": "",
+    "More posts about %s": "Още публикации относно %s",
     "Newer posts": "Нови публикации",
     "Next post": "Следваща публикация",
+    "No posts found.": "",
+    "Nothing found.": "",
     "Older posts": "Стари публикации",
     "Original site": "Оригиналния сайт",
-    "Posted": "Публиковано",
+    "Posted:": "Публиковано:",
     "Posts about %s": "Публикации относно %s",
     "Posts for year %s": "Публикации за %s година",
     "Posts for {month} {year}": "Публикации за {month} {year}",
     "Previous post": "Предишна публикация",
+    "Publication date": "",
+    "RSS feed": "",
     "Read in English": "Прочетете на български",
     "Read more": "Прочети още",
     "Source": "Source",
     "Tags and Categories": "Тагове и Категории",
     "Tags": "Тагове",
-    "old posts page %d": "стари публикации страница %d",
+    "old posts, page %d": "стари публикации, страница %d",
+    "page %d": "страница %d",
 }
