@@ -2,24 +2,32 @@
 from __future__ import unicode_literals
 
 MESSAGES = {
-    "Also available in": "També disponibles en",
+    "%d min remaining to read": "",
+    "Also available in:": "També disponibles en:",
     "Archive": "Arxiu",
     "Categories": "",
+    "Comments": "",
     "LANGUAGE": "Català",
-    "More posts about": "Més entrades sobre",
+    "Languages:": "",
+    "More posts about %s": "Més entrades sobre %s",
     "Newer posts": "Entrades posteriors",
     "Next post": "Entrada següent",
+    "No posts found.": "",
+    "Nothing found.": "",
     "Older posts": "Entrades anteriors",
     "Original site": "Lloc original",
-    "Posted": "Publicat",
+    "Posted:": "Publicat:",
     "Posts about %s": "Entrades sobre %s",
     "Posts for year %s": "Entrades de l'any %s",
     "Posts for {month} {year}": "",
     "Previous post": "Entrada anterior",
+    "Publication date": "",
+    "RSS feed": "",
     "Read in English": "Llegeix-ho en català",
     "Read more": "Llegeix-ne més",
     "Source": "Codi",
     "Tags and Categories": "",
     "Tags": "Etiquetes",
-    "old posts page %d": "entrades antigues pàgina %d",
+    "old posts, page %d": "entrades antigues, pàgina %d",
+    "page %d": "pàgina %d",
 }
