@@ -2,24 +2,32 @@
 from __future__ import unicode_literals
 
 MESSAGES = {
-    "Also available in": "Auch verfügbar in",
+    "%d min remaining to read": "",
+    "Also available in:": "Auch verfügbar in:",
     "Archive": "Archiv",
     "Categories": "Kategorien",
+    "Comments": "Kommentare",
     "LANGUAGE": "Deutsch",
-    "More posts about": "Weitere Einträge über",
+    "Languages:": "Sprachen:",
+    "More posts about %s": "Weitere Einträge über %s",
     "Newer posts": "Neuere Einträge",
     "Next post": "Nächster Eintrag",
+    "No posts found.": "Keine Einträge gefunden.",
+    "Nothing found.": "Nichts gefunden.",
     "Older posts": "Ältere Einträge",
     "Original site": "Original-Seite",
-    "Posted": "Veröffentlicht",
+    "Posted:": "Veröffentlicht:",
     "Posts about %s": "Einträge über %s",
     "Posts for year %s": "Einträge aus dem Jahr %s",
     "Posts for {month} {year}": "Einträge aus {month} {year}",
     "Previous post": "Vorheriger Eintrag",
+    "Publication date": "Veröffentlichungsdatum",
+    "RSS feed": "RSS-Feed",
     "Read in English": "Auf Deutsch lesen",
     "Read more": "Weiterlesen",
     "Source": "Source",
     "Tags and Categories": "Tags und Kategorien",
     "Tags": "Tags",
-    "old posts page %d": "Vorherige Einträge %d",
+    "old posts, page %d": "Vorherige Einträge, Seite %d",
+    "page %d": "Seite %d",
 }
