@@ -2,24 +2,32 @@
 from __future__ import unicode_literals
 
 MESSAGES = {
-    "Also available in": "Διαθέσιμο και στα",
+    "%d min remaining to read": "",
+    "Also available in:": "Διαθέσιμο και στα:",
     "Archive": "Αρχείο",
     "Categories": "Κατηγορίες",
+    "Comments": "",
     "LANGUAGE": "Ελληνικά",
-    "More posts about": "Περισσότερες αναρτήσεις για",
+    "Languages:": "",
+    "More posts about %s": "Περισσότερες αναρτήσεις για %s",
     "Newer posts": "Νεότερες αναρτήσεις",
     "Next post": "Επόμενη ανάρτηση",
+    "No posts found.": "",
+    "Nothing found.": "",
     "Older posts": "Παλαιότερες αναρτήσεις",
     "Original site": "Ιστοσελίδα αρχικής ανάρτησης",
-    "Posted": "Αναρτήθηκε",
+    "Posted:": "Αναρτήθηκε:",
     "Posts about %s": "Αναρτήσεις για %s",
     "Posts for year %s": "Αναρτήσεις για το έτος %s",
     "Posts for {month} {year}": "Αναρτήσεις για τον {month} του {year}",
     "Previous post": "Προηγούμενη ανάρτηση",
+    "Publication date": "",
+    "RSS feed": "",
     "Read in English": "Διαβάστε στα Ελληνικά",
     "Read more": "Διαβάστε περισσότερα",
     "Source": "Πηγαίος κώδικας",
-    "Tags and Categories": "",
+    "Tags and Categories": "Ετικέτες και κατηγορίες",
     "Tags": "Ετικέτες",
-    "old posts page %d": "σελίδα παλαιότερων αναρτήσεων %d",
+    "old posts, page %d": "σελίδα παλαιότερων αναρτήσεων %d",
+    "page %d": "σελίδα %d",
 }
