@@ -2,26 +2,32 @@
 from __future__ import unicode_literals
 
 MESSAGES = {
-    "Also available in": "Also available in",
+    "%d min remaining to read": "%d min remaining to read",
+    "Also available in:": "Also available in:",
     "Archive": "Archive",
     "Categories": "Categories",
+    "Comments": "Comments",
     "LANGUAGE": "English",
-    "More posts about": "More posts about",
+    "Languages:": "Languages:",
+    "More posts about %s": "More posts about %s",
     "Newer posts": "Newer posts",
     "Next post": "Next post",
-    "No content": "",
-    "No title": "",
+    "No posts found.": "No posts found.",
+    "Nothing found.": "Nothing found.",
     "Older posts": "Older posts",
     "Original site": "Original site",
-    "Posted": "Posted",
+    "Posted:": "Posted:",
     "Posts about %s": "Posts about %s",
     "Posts for year %s": "Posts for year %s",
     "Posts for {month} {year}": "Posts for {month} {year}",
     "Previous post": "Previous post",
+    "Publication date": "Publication date",
+    "RSS feed": "RSS feed",
     "Read in English": "Read in English",
     "Read more": "Read more",
     "Source": "Source",
     "Tags and Categories": "Tags and Categories",
     "Tags": "Tags",
-    "old posts page %d": "old posts page %d",
+    "old posts, page %d": "old posts, page %d",
+    "page %d": "page %d",
 }
