@@ -2,24 +2,32 @@
 from __future__ import unicode_literals
 
 MESSAGES = {
-    "Also available in": "Ankaŭ disponebla en",
+    "%d min remaining to read": "",
+    "Also available in:": "Ankaŭ disponebla en:",
     "Archive": "Arĥivo",
     "Categories": "Kategorioj",
+    "Comments": "",
     "LANGUAGE": "Anglalingve",
-    "More posts about": "Pli artikoloj pri...",
+    "Languages:": "",
+    "More posts about %s": "Pli artikoloj pri %s",
     "Newer posts": "Pli novaj artikoloj",
     "Next post": "Venonta artikolo",
+    "No posts found.": "",
+    "Nothing found.": "",
     "Older posts": "Pli malnovaj artikoloj",
     "Original site": "Originala interretejo",
-    "Posted": "Skribita",
+    "Posted:": "Skribita:",
     "Posts about %s": "Artikoloj pri %s",
     "Posts for year %s": "Artikoloj de la jaro %s",
     "Posts for {month} {year}": "Artikoloj skribitaj en {month} {year}",
     "Previous post": "Antaŭa artikolo",
+    "Publication date": "",
+    "RSS feed": "",
     "Read in English": "Legu ĝin en Esperanto",
     "Read more": "Legu plu",
     "Source": "Fonto",
     "Tags and Categories": "Etikedoj kaj Kategorioj",
     "Tags": "Etikedoj",
-    "old posts page %d": "paĝo de malnovaj artikoloj %d",
+    "old posts, page %d": "paĝo de malnovaj artikoloj %d",
+    "page %d": "paĝo %d",
 }
