@@ -2,24 +2,32 @@
 from __future__ import unicode_literals
 
 MESSAGES = {
-    "Also available in": "همچنین قابل دسترس از",
+    "%d min remaining to read": "",
+    "Also available in:": "همچنین قابل دسترس از:",
     "Archive": "آرشیو",
     "Categories": "دسته‌ها",
+    "Comments": "دیدگاه‌‌‌ها",
     "LANGUAGE": "فارسی",
-    "More posts about": "ارسال‌های بیشتر دربارهٔ",
+    "Languages:": "زبان‌‌ها:",
+    "More posts about %s": "ارسال‌های بیشتر دربارهٔ%s",
     "Newer posts": "ارسال‌های جدید‌تر",
     "Next post": "ارسال بعدی",
+    "No posts found.": "هیچ پستی پیدا نشد.",
+    "Nothing found.": "هیچ‌چیزی پیدا نشد.",
     "Older posts": "پست‌های قدیمی‌تر",
     "Original site": "سایت اصلی",
-    "Posted": "ارسال شده",
+    "Posted:": "ارسال شده:",
     "Posts about %s": "ارسال‌ها دربارهٔ %s",
     "Posts for year %s": "ارسال‌ها برای سال %s",
     "Posts for {month} {year}": "ارسال برای {month} {year}",
     "Previous post": "ارسال پیشین",
+    "Publication date": "تاریخ انتشار",
+    "RSS feed": "خوراک",
     "Read in English": "به فارسی بخوانید",
     "Read more": "بیشتر بخوانید",
     "Source": "منبع",
     "Tags and Categories": "برچسب‌ها و دسته‌ها",
     "Tags": "برچسب‌ها",
-    "old posts page %d": "صفحهٔ ارسال‌های قدیمی %d",
+    "old posts, page %d": "صفحهٔ ارسال‌های قدیمی %d",
+    "page %d": "برگه %d",
 }
