@@ -2,24 +2,32 @@
 from __future__ import unicode_literals
 
 MESSAGES = {
-    "Also available in": "Também disponível em",
+    "%d min remaining to read": "%d mín restante para leitura",
+    "Also available in:": "Também disponível em:",
     "Archive": "Arquivo",
     "Categories": "Categorias",
+    "Comments": "Comentários",
     "LANGUAGE": "Português",
-    "More posts about": "Mais posts sobre",
+    "Languages:": "Idiomas:",
+    "More posts about %s": "Mais posts sobre %s",
     "Newer posts": "Posts mais recentes",
     "Next post": "Próximo post",
+    "No posts found.": "Nenhum tópico encontrado.",
+    "Nothing found.": "Nada encontrado.",
     "Older posts": "Posts mais antigos",
     "Original site": "Site original",
-    "Posted": "Publicado",
+    "Posted:": "Publicado:",
     "Posts about %s": "Posts sobre %s",
     "Posts for year %s": "Posts do ano %s",
     "Posts for {month} {year}": "Posts de {month} {year}",
     "Previous post": "Post anterior",
+    "Publication date": "Data de publicação",
+    "RSS feed": "Feed RSS",
     "Read in English": "Ler em português",
     "Read more": "Leia mais",
     "Source": "Código",
     "Tags and Categories": "Tags e Categorias",
     "Tags": "Tags",
-    "old posts page %d": "Posts antigos página %d",
+    "old posts, page %d": "Posts antigos, página %d",
+    "page %d": "página %d",
 }
