@@ -2,24 +2,32 @@
 from __future__ import unicode_literals
 
 MESSAGES = {
-    "Also available in": "Также доступно на",
+    "%d min remaining to read": "%d минут чтения осталось",
+    "Also available in:": "Также доступно на:",
     "Archive": "Архив",
     "Categories": "Категории",
+    "Comments": "Комментарии",
     "LANGUAGE": "Русский",
-    "More posts about": "Больше записей о",
+    "Languages:": "Языки:",
+    "More posts about %s": "Больше записей о %s",
     "Newer posts": "Новые записи",
     "Next post": "Следующая запись",
+    "No posts found.": "Записей не найдено.",
+    "Nothing found.": "Ничего не найдено.",
     "Older posts": "Старые записи",
     "Original site": "Оригинальный сайт",
-    "Posted": "Опубликовано",
+    "Posted:": "Опубликовано:",
     "Posts about %s": "Записи о %s",
     "Posts for year %s": "Записи за %s год",
     "Posts for {month} {year}": "Записи за {month} {year}",
     "Previous post": "Предыдущая запись",
+    "Publication date": "Дата опубликования",
+    "RSS feed": "RSS лента",
     "Read in English": "Прочесть по-русски",
     "Read more": "Читать далее",
     "Source": "Источник",
     "Tags and Categories": "Тэги и категории",
     "Tags": "Тэги",
-    "old posts page %d": "%d страница со старыми записями",
+    "old posts, page %d": "%d страница со старыми записями",
+    "page %d": "%d страница",
 }
