@@ -2,24 +2,32 @@
 from __future__ import unicode_literals
 
 MESSAGES = {
-    "Also available in": "其他语言版本",
+    "%d min remaining to read": "",
+    "Also available in:": "其他语言版本：",
     "Archive": "文章存档",
-    "Categories": "",
+    "Categories": "分类",
+    "Comments": "",
     "LANGUAGE": "简体中文",
-    "More posts about": "更多相关文章：",
+    "Languages:": "",
+    "More posts about %s": "更多相关文章： %s",
     "Newer posts": "新一篇",
     "Next post": "后一篇",
+    "No posts found.": "",
+    "Nothing found.": "",
     "Older posts": "旧一篇",
     "Original site": "原文地址",
-    "Posted": "发表于",
+    "Posted:": "发表于：",
     "Posts about %s": "文章分类：%s",
     "Posts for year %s": "%s年文章",
     "Posts for {month} {year}": "{year}年{month}月文章",
     "Previous post": "前一篇",
+    "Publication date": "",
+    "RSS feed": "",
     "Read in English": "中文版",
     "Read more": "更多",
     "Source": "源代码",
-    "Tags and Categories": "",
+    "Tags and Categories": "标签和分类",
     "Tags": "标签",
-    "old posts page %d": "旧文章页 %d",
+    "old posts, page %d": "旧文章页 %d",
+    "page %d": "",
 }
