@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright © 2012-2013 Roberto Alsina and others.
+# Copyright © 2012-2014 Roberto Alsina and others.
 
 # Permission is hereby granted, free of charge, to any
 # person obtaining a copy of this software and associated
@@ -36,6 +36,7 @@ try:
 except ImportError:
     from urllib.parse import urljoin  # NOQA
 
+import natsort
 Image = None
 try:
     from PIL import Image, ExifTags  # NOQA
@@ -46,11 +47,13 @@ except ImportError:
         Image = _Image
     except ImportError:
         pass
+
 import PyRSS2Gen as rss
 
 from nikola.plugin_categories import Task
 from nikola import utils
 from nikola.post import Post
+from nikola.utils import req_missing
 
 
 class Galleries(Task):
@@ -77,6 +80,9 @@ class Galleries(Task):
     def gen_tasks(self):
         """Render image galleries."""
 
+        if Image is None:
+            req_missing(['pillow'], 'render galleries')
+
         self.logger = utils.get_logger('render_galleries', self.site.loghandlers)
         self.image_ext_list = ['.jpg', '.png', '.jpeg', '.gif', '.svg', '.bmp', '.tiff']
         self.image_ext_list.extend(self.site.config.get('EXTRA_IMAGE_EXTENSIONS', []))
@@ -93,9 +99,15 @@ class Galleries(Task):
             'filters': self.site.config['FILTERS'],
             'translations': self.site.config['TRANSLATIONS'],
             'global_context': self.site.GLOBAL_CONTEXT,
-            "feed_length": self.site.config['FEED_LENGTH'],
+            'feed_length': self.site.config['FEED_LENGTH'],
+            'tzinfo': self.site.tzinfo,
+            'comments_in_galleries': self.site.config['COMMENTS_IN_GALLERIES'],
+            'generate_rss': self.site.config['GENERATE_RSS'],
         }
 
+        for k, v in self.site.GLOBAL_CONTEXT['template_hooks'].items():
+            self.kw['||template_hooks|{0}||'.format(k)] = v._items
+
         yield self.group_task()
 
         template_name = "gallery.tmpl"
@@ -111,7 +123,7 @@ class Galleries(Task):
         for gallery in self.gallery_list:
 
             # Create subfolder list
-            folder_list = [x.split(os.sep)[-2] for x in
+            folder_list = [(x, x.split(os.sep)[-2]) for x in
                            glob.glob(os.path.join(gallery, '*') + os.sep)]
 
             # Parse index into a post (with translations)
@@ -137,7 +149,7 @@ class Galleries(Task):
                 for task in self.remove_excluded_image(image):
                     yield task
 
-            crumbs = utils.get_crumbs(gallery)
+            crumbs = utils.get_crumbs(gallery, index_folder=self)
 
             # Create index.html for each language
             for lang in self.kw['translations']:
@@ -148,6 +160,9 @@ class Galleries(Task):
                         os.path.relpath(gallery, self.kw['gallery_path']), lang))
                 dst = os.path.normpath(dst)
 
+                for k in self.site._GLOBAL_CONTEXT_TRANSLATABLE:
+                    self.kw[k] = self.site.GLOBAL_CONTEXT[k](lang)
+
                 context = {}
                 context["lang"] = lang
                 if post:
@@ -161,38 +176,50 @@ class Galleries(Task):
                 if self.kw['use_filename_as_title']:
                     img_titles = []
                     for fn in image_name_list:
-                        name_without_ext = os.path.splitext(fn)[0]
-                        img_titles.append(
-                            'id="{0}" alt="{1}" title="{2}"'.format(
-                                name_without_ext,
-                                name_without_ext,
-                                utils.unslugify(name_without_ext)))
+                        name_without_ext = os.path.splitext(os.path.basename(fn))[0]
+                        img_titles.append(utils.unslugify(name_without_ext))
                 else:
                     img_titles = [''] * len(image_name_list)
 
                 thumbs = ['.thumbnail'.join(os.path.splitext(p)) for p in image_list]
                 thumbs = [os.path.join(self.kw['output_folder'], t) for t in thumbs]
+                dest_img_list = [os.path.join(self.kw['output_folder'], t) for t in image_list]
 
-                ## TODO: in v7 remove images from context, use photo_array
-                context["images"] = list(zip(image_name_list, thumbs, img_titles))
-                context["folders"] = folder_list
+                folders = []
+
+                # Generate friendly gallery names
+                for path, folder in folder_list:
+                    fpost = self.parse_index(path)
+                    if fpost:
+                        ft = fpost.title(lang) or folder
+                    else:
+                        ft = folder
+                    folders.append((folder, ft))
+
+                context["folders"] = natsort.natsorted(folders)
                 context["crumbs"] = crumbs
                 context["permalink"] = self.site.link(
-                    "gallery", os.path.basename(gallery), lang)
-                # FIXME: use kw
-                context["enable_comments"] = (
-                    self.site.config["COMMENTS_IN_GALLERIES"])
+                    "gallery", os.path.basename(
+                        os.path.relpath(gallery, self.kw['gallery_path'])), lang)
+                context["enable_comments"] = self.kw['comments_in_galleries']
                 context["thumbnail_size"] = self.kw["thumbnail_size"]
 
-                # FIXME: render post in a task
                 if post:
-                    post.compile(lang)
-                    context['text'] = post.text(lang)
+                    yield {
+                        'basename': self.name,
+                        'name': post.translated_base_path(lang),
+                        'targets': [post.translated_base_path(lang)],
+                        'file_dep': post.fragment_deps(lang),
+                        'actions': [(post.compile, [lang])],
+                        'uptodate': [utils.config_changed(self.kw)]
+                    }
+                    context['post'] = post
                 else:
-                    context['text'] = ''
-
+                    context['post'] = None
                 file_dep = self.site.template_system.template_deps(
                     template_name) + image_list + thumbs
+                if post:
+                    file_dep += [post.translated_base_path(l) for l in self.kw['translations']]
 
                 yield utils.apply_filters({
                     'basename': self.name,
@@ -204,7 +231,8 @@ class Galleries(Task):
                             template_name,
                             dst,
                             context,
-                            image_list,
+                            dest_img_list,
+                            img_titles,
                             thumbs,
                             file_dep))],
                     'clean': True,
@@ -216,39 +244,40 @@ class Galleries(Task):
                 }, self.kw['filters'])
 
                 # RSS for the gallery
-                rss_dst = os.path.join(
-                    self.kw['output_folder'],
-                    self.site.path(
-                        "gallery_rss",
-                        os.path.relpath(gallery, self.kw['gallery_path']), lang))
-                rss_dst = os.path.normpath(rss_dst)
+                if self.kw["generate_rss"]:
+                    rss_dst = os.path.join(
+                        self.kw['output_folder'],
+                        self.site.path(
+                            "gallery_rss",
+                            os.path.relpath(gallery, self.kw['gallery_path']), lang))
+                    rss_dst = os.path.normpath(rss_dst)
 
-                yield utils.apply_filters({
-                    'basename': self.name,
-                    'name': rss_dst,
-                    'file_dep': file_dep,
-                    'targets': [rss_dst],
-                    'actions': [
-                        (self.gallery_rss, (
-                            image_list,
-                            img_titles,
-                            lang,
-                            self.site.link(
-                                "gallery_rss", os.path.basename(gallery), lang),
-                            rss_dst,
-                            context['title']
-                        ))],
-                    'clean': True,
-                    'uptodate': [utils.config_changed({
-                        1: self.kw,
-                    })],
-                }, self.kw['filters'])
+                    yield utils.apply_filters({
+                        'basename': self.name,
+                        'name': rss_dst,
+                        'file_dep': file_dep,
+                        'targets': [rss_dst],
+                        'actions': [
+                            (self.gallery_rss, (
+                                image_list,
+                                img_titles,
+                                lang,
+                                self.site.link(
+                                    "gallery_rss", os.path.basename(gallery), lang),
+                                rss_dst,
+                                context['title']
+                            ))],
+                        'clean': True,
+                        'uptodate': [utils.config_changed({
+                            1: self.kw,
+                        })],
+                    }, self.kw['filters'])
 
     def find_galleries(self):
         """Find all galleries to be processed according to conf.py"""
 
         self.gallery_list = []
-        for root, dirs, files in os.walk(self.kw['gallery_path']):
+        for root, dirs, files in os.walk(self.kw['gallery_path'], followlinks=True):
             self.gallery_list.append(root)
 
     def create_galleries(self):
@@ -288,8 +317,14 @@ class Galleries(Task):
                 False,
                 self.site.MESSAGES,
                 'story.tmpl',
-                self.site.get_compiler(index_path).compile_html
+                self.site.get_compiler(index_path)
             )
+            # If this did not exist, galleries without a title in the
+            # index.txt file would be errorneously named `index`
+            # (warning: galleries titled index and filenamed differently
+            #  may break)
+            if post.title == 'index':
+                post.title = os.path.split(gallery)[1]
         else:
             post = None
         return post
@@ -410,6 +445,7 @@ class Galleries(Task):
             output_name,
             context,
             img_list,
+            img_titles,
             thumbs,
             file_dep):
         """Build the gallery index."""
@@ -423,12 +459,9 @@ class Galleries(Task):
             return url
 
         photo_array = []
-        for img, thumb in zip(img_list, thumbs):
+        for img, thumb, title in zip(img_list, thumbs, img_titles):
             im = Image.open(thumb)
             w, h = im.size
-            title = ''
-            if self.kw['use_filename_as_title']:
-                title = utils.unslugify(os.path.splitext(img)[0])
             # Thumbs are files in output, we need URLs
             photo_array.append({
                 'url': url_from_path(img),
@@ -439,9 +472,8 @@ class Galleries(Task):
                     'h': h
                 },
             })
-        context['photo_array_json'] = json.dumps(photo_array)
         context['photo_array'] = photo_array
-
+        context['photo_array_json'] = json.dumps(photo_array)
         self.site.render_template(template_name, output_name, context)
 
     def gallery_rss(self, img_list, img_titles, lang, permalink, output_path, title):
@@ -455,12 +487,12 @@ class Galleries(Task):
             return urljoin(self.site.config['BASE_URL'], url)
 
         items = []
-        for img, full_title in list(zip(img_list, img_titles))[:self.kw["feed_length"]]:
+        for img, title in list(zip(img_list, img_titles))[:self.kw["feed_length"]]:
             img_size = os.stat(
                 os.path.join(
                     self.site.config['OUTPUT_FOLDER'], img)).st_size
             args = {
-                'title': full_title.split('"')[-2],
+                'title': title,
                 'link': make_url(img),
                 'guid': rss.Guid(img, False),
                 'pubDate': self.image_date(img),
@@ -471,17 +503,16 @@ class Galleries(Task):
                 ),
             }
             items.append(rss.RSSItem(**args))
-        rss_obj = utils.ExtendedRSS2(
+        rss_obj = rss.RSS2(
             title=title,
             link=make_url(permalink),
             description='',
             lastBuildDate=datetime.datetime.now(),
             items=items,
-            generator='nikola',
+            generator='http://getnikola.com/',
             language=lang
         )
-        rss_obj.self_url = make_url(permalink)
-        rss_obj.rss_attrs["xmlns:atom"] = "http://www.w3.org/2005/Atom"
+        rss_obj.rss_attrs["xmlns:dc"] = "http://purl.org/dc/elements/1.1/"
         dst_dir = os.path.dirname(output_path)
         utils.makedirs(dst_dir)
         with codecs.open(output_path, "wb+", "utf-8") as rss_file:
@@ -523,8 +554,9 @@ class Galleries(Task):
             try:
                 im.thumbnail(size, Image.ANTIALIAS)
                 im.save(dst)
-            except Exception:
-                self.logger.warn("Can't thumbnail {0}, using original image as thumbnail".format(src))
+            except Exception as e:
+                self.logger.warn("Can't thumbnail {0}, using original "
+                                 "image as thumbnail ({1})".format(src, e))
                 utils.copy_file(src, dst)
         else:  # Image is small
             utils.copy_file(src, dst)
@@ -540,7 +572,7 @@ class Galleries(Task):
             if exif is not None:
                 for tag, value in list(exif.items()):
                     decoded = ExifTags.TAGS.get(tag, tag)
-                    if decoded == 'DateTimeOriginal':
+                    if decoded in ('DateTimeOriginal', 'DateTimeDigitized'):
                         try:
                             self.dates[src] = datetime.datetime.strptime(
                                 value, r'%Y:%m:%d %H:%M:%S')
